==> eiffelstudio-18.11.10.2592.tar: F_code/C12/xm575.c <==
/*
 * Code for class XML_FILE_INPUT_STREAM
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm575.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XML_FILE_INPUT_STREAM}.make */
void F1141_10149 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = F876_7717(RTCW(arg1));
	tr1 = F1152_10596(RTCW(tr1));
	F1141_10153(Current, tr1);
	tr1 = RTLNSMART(eif_new_type(1131, 1).id);
	F1124_9589(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 4096L);
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R6774[Dtype(arg1)-857])(RTCW(arg1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.name */
EIF_REFERENCE F1141_10152 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {XML_FILE_INPUT_STREAM}.set_name */
void F1141_10153 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
}

/* {XML_FILE_INPUT_STREAM}.end_of_input */
EIF_BOOLEAN F1141_10156 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_INTEGER_32 ti4_5;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	
	
	Result = *(EIF_BOOLEAN *)(Current+ _CHROFF_3_1_);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_);
	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_);
	ti4_3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_);
	ti4_4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_);
	ti4_5 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (Result && ((EIF_BOOLEAN) ((EIF_BOOLEAN) (ti4_1 > ti4_2) && (EIF_BOOLEAN) ((EIF_INTEGER_32) ((EIF_INTEGER_32) (ti4_3 - ti4_4) + ((EIF_INTEGER_32) 1L)) < ti4_5))));
	return Result;
}

/* {XML_FILE_INPUT_STREAM}.index */
EIF_INTEGER_32 F1141_10158 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_);
}


/* {XML_FILE_INPUT_STREAM}.line */
EIF_INTEGER_32 F1141_10159 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_5_);
}


/* {XML_FILE_INPUT_STREAM}.column */
EIF_INTEGER_32 F1141_10160 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_);
}


/* {XML_FILE_INPUT_STREAM}.last_character */
EIF_CHARACTER_8 F1141_10161 (EIF_REFERENCE Current)
{
	return *(EIF_CHARACTER_8 *)(Current+ _CHROFF_3_0_);
}


/* {XML_FILE_INPUT_STREAM}.compute_smart_chunk_size */
void F1141_10164 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN) (arg1 > ((EIF_INTEGER_32) 0L))) {
		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 100L));
	} else {
		loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_0_);
		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 / ((EIF_INTEGER_32) 100L));
	}
	if ((EIF_BOOLEAN) (loc1 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_))) {
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_);
		ti4_1 = eif_max_int32 (ti4_1,(EIF_INTEGER_32) (loc1 - (EIF_INTEGER_32) (loc1 % ((EIF_INTEGER_32) 4096L))));
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) = (EIF_INTEGER_32) ti4_1;
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (arg2 > ((EIF_INTEGER_32) 0L)) && (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) > arg2))) {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) = (EIF_INTEGER_32) arg2;
		}
	}
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.start */
void F1141_10165 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tb1 = '\0';
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_3_2_)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tb2 = F876_7765(RTCW(tr1));
		tb1 = (EIF_BOOLEAN) !tb2;
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F876_7775(RTCW(tr1));
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F876_7793(RTCW(tr1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_5_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	F1141_10169(Current);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_3_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.close */
void F1141_10166 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	tr1 = RTLNSMART(eif_new_type(1131, 1).id);
	F1124_9589(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_3_2_)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F876_7792(RTCW(tr1));
	}
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.read_character */
void F1141_10167 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_8 loc1 = (EIF_CHARACTER_8) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_))++;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_3_1_)) {
		F1141_10165(Current);
	}
	if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) <= *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_))) {
		loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_);
		loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 1L) + loc2) - ti4_1);
		tr1 = *(EIF_REFERENCE *)(Current);
		tb1 = F1124_9601(RTCW(tr1), loc2);
		if (tb1) {
			tr1 = *(EIF_REFERENCE *)(Current);
			loc1 = *(EIF_CHARACTER_8 *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R7069[Dtype(tr1)-905])(RTCW(tr1), loc2));
		} else {
			loc1 = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '\000';
		}
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) == *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_))) {
			F1141_10169(Current);
		}
		if ((EIF_BOOLEAN)(*(EIF_CHARACTER_8 *)(Current+ _CHROFF_3_0_) == (EIF_CHARACTER_8) '\012')) {
			(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_5_))++;
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
		} else {
			(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_))++;
		}
	} else {
		loc1 = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '\000';
	}
	*(EIF_CHARACTER_8 *)(Current+ _CHROFF_3_0_) = (EIF_CHARACTER_8) loc1;
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.get_next_chunk */
void F1141_10169 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R6892[Dtype(tr1)-875])(RTCW(tr1));
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R6024[Dtype(tr1)-875])(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_));
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O5958[Dtype(tr1)-526]);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	} else {
		tr1 = RTLNSMART(eif_new_type(1131, 1).id);
		F1124_9589(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_) = (EIF_INTEGER_32) (EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) + ((EIF_INTEGER_32) 1L));
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1) + O8415[Dtype(tr1)-1129]);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_) = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_) + ti4_1) - ((EIF_INTEGER_32) 1L));
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.current_chunk */
EIF_REFERENCE F1141_10172 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {XML_FILE_INPUT_STREAM}.source */
EIF_REFERENCE F1141_10174 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit575 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C12/xm575.c <==
/*
 * Code for class XML_FILE_INPUT_STREAM
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm575.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XML_FILE_INPUT_STREAM}.make */
void F1141_10154 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = F877_7737(RTCW(arg1));
	tr1 = F1153_10645(RTCW(tr1));
	F1141_10158(Current, tr1);
	tr1 = RTLNSMART(eif_new_type(1132, 1).id);
	F1125_9612(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 4096L);
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R6789[Dtype(RTCW(arg1))-858])(arg1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_0_) = (EIF_INTEGER_32) ti4_1;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.name */
EIF_REFERENCE F1141_10157 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {XML_FILE_INPUT_STREAM}.set_name */
void F1141_10158 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
}

/* {XML_FILE_INPUT_STREAM}.end_of_input */
EIF_BOOLEAN F1141_10161 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_INTEGER_32 ti4_5;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	
	
	Result = *(EIF_BOOLEAN *)(Current+ _CHROFF_3_1_);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_);
	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_);
	ti4_3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_);
	ti4_4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_);
	ti4_5 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (Result && ((EIF_BOOLEAN) ((EIF_BOOLEAN) (ti4_1 > ti4_2) && (EIF_BOOLEAN) ((EIF_INTEGER_32) ((EIF_INTEGER_32) (ti4_3 - ti4_4) + ((EIF_INTEGER_32) 1L)) < ti4_5))));
	return Result;
}

/* {XML_FILE_INPUT_STREAM}.index */
EIF_INTEGER_32 F1141_10163 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_);
}


/* {XML_FILE_INPUT_STREAM}.line */
EIF_INTEGER_32 F1141_10164 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_5_);
}


/* {XML_FILE_INPUT_STREAM}.column */
EIF_INTEGER_32 F1141_10165 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_);
}


/* {XML_FILE_INPUT_STREAM}.last_character */
EIF_CHARACTER_8 F1141_10166 (EIF_REFERENCE Current)
{
	return *(EIF_CHARACTER_8 *)(Current+ _CHROFF_3_0_);
}


/* {XML_FILE_INPUT_STREAM}.compute_smart_chunk_size */
void F1141_10169 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN) (arg1 > ((EIF_INTEGER_32) 0L))) {
		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 100L));
	} else {
		loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_0_);
		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 / ((EIF_INTEGER_32) 100L));
	}
	if ((EIF_BOOLEAN) (loc1 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_))) {
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_);
		ti4_1 = eif_max_int32 (ti4_1,(EIF_INTEGER_32) (loc1 - (EIF_INTEGER_32) (loc1 % ((EIF_INTEGER_32) 4096L))));
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) = (EIF_INTEGER_32) ti4_1;
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (arg2 > ((EIF_INTEGER_32) 0L)) && (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) > arg2))) {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_) = (EIF_INTEGER_32) arg2;
		}
	}
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.start */
void F1141_10170 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tb1 = '\0';
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_3_2_)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tb2 = F877_7787(RTCW(tr1));
		tb1 = (EIF_BOOLEAN) !tb2;
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F877_7797(RTCW(tr1));
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F877_7815(RTCW(tr1));
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_5_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	F1141_10174(Current);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_3_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.close */
void F1141_10171 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	tr1 = RTLNSMART(eif_new_type(1132, 1).id);
	F1125_9612(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_3_2_)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F877_7814(RTCW(tr1));
	}
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.read_character */
void F1141_10172 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_8 loc1 = (EIF_CHARACTER_8) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_))++;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_3_1_)) {
		F1141_10170(Current);
	}
	if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) <= *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_))) {
		loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_);
		loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 1L) + loc2) - ti4_1);
		tr1 = *(EIF_REFERENCE *)(Current);
		tb1 = F1125_9624(RTCW(tr1), loc2);
		if (tb1) {
			tr1 = *(EIF_REFERENCE *)(Current);
			loc1 = F1133_9982(RTCW(tr1), loc2);
		} else {
			loc1 = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '\000';
		}
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) == *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_))) {
			F1141_10174(Current);
		}
		if ((EIF_BOOLEAN)(*(EIF_CHARACTER_8 *)(Current+ _CHROFF_3_0_) == (EIF_CHARACTER_8) '\012')) {
			(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_5_))++;
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
		} else {
			(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_4_))++;
		}
	} else {
		loc1 = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '\000';
	}
	*(EIF_CHARACTER_8 *)(Current+ _CHROFF_3_0_) = (EIF_CHARACTER_8) loc1;
	RTLE;
}

/* {XML_FILE_INPUT_STREAM}.get_next_chunk */
void F1141_10174 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tb1 = F877_7785(RTCW(tr1));
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R6030[Dtype(RTCW(tr1))-877])(tr1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_1_));
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	} else {
		tr1 = RTLNSMART(eif_new_type(1132, 1).id);
		F1125_9612(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_) = (EIF_INTEGER_32) (EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_6_) + ((EIF_INTEGER_32) 1L));
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1) + O8435[Dtype(tr1)-1130]);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_3_) = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_3_0_2_) + ti4_1) - ((EIF_INTEGER_32) 1L));
	RTLE;
}

void EIF_Minit575 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
